@@ -7,7 +7,7 @@ from typing import Union
 
 from . import handlers
 from .chain import Chain
-from .core import get_event_params
+from .core import VERSION, get_event_params
 
 
 class Handler:
@@ -35,19 +35,19 @@ class Bot:
     async def run_polling(self) -> None:
         async with aiohttp.ClientSession() as session:
             async with session.get("https://api.vk.com/method/groups.getLongPollServer",
-                                   params=f"group_id={self.group_id}&access_token={self.token}&v=5.126") as response:
+                                   params=f"group_id={self.group_id}&access_token={self.token}&v={VERSION}") as response:
                 config = await response.json()
                 print(config)
                 self.config = config["response"]
                 self.config["server"] = self.config["server"].replace("https://", "")
 
                 async with session.get("https://api.vk.com/method/groups.getLongPollSettings",
-                                       params=f"group_id={self.group_id}&access_token={self.token}&v=5.126") as response:
+                                       params=f"group_id={self.group_id}&access_token={self.token}&v={VERSION}") as response:
                     print(await response.json())
 
                 while True:
                     try:
-                        async with session.get("https://%s?act=a_check&key=%s&ts=%s&wait=60&mode=2&version=5.126" % (
+                        async with session.get(f"https://%s?act=a_check&key=%s&ts=%s&wait=60&mode=2&version={VERSION}" % (
                         self.config["server"], self.config["key"], self.config["ts"])) as response:
                             event = await response.json()
                             updates = event["updates"]
@@ -92,7 +92,7 @@ class Bot:
         query = f"https://api.vk.com/method/{method}?"
         for key, value in params.items():
             query += f"{key}={value}&"
-        query += f"access_token={self.token}&v=5.126"
+        query += f"access_token={self.token}&v={VERSION}"
 
         async with aiohttp.ClientSession() as session:
             async with session.get(query) as response:
