@@ -1,9 +1,13 @@
+VERSION = "5.199"
+
+
 def get_event_params(event: dict, event_type: str) -> dict:
     text = None
     user_id = None
     peer_id = None
     post_id = None
     owner_id = None
+    reply_message = {}
 
     try:
         if event_type == "message_new":
@@ -11,11 +15,25 @@ def get_event_params(event: dict, event_type: str) -> dict:
             peer_id = event["object"]["message"]["peer_id"]
             user_id = event["object"]["message"]["from_id"]
 
+            if "reply_message" in event["object"]["message"]:
+                reply_message = {
+                    "text": event["object"]["message"]["reply_message"]["text"],
+                    "peer_id": event["object"]["message"]["reply_message"]["peer_id"],
+                    "user_id": event["object"]["message"]["reply_message"]["from_id"]
+                }
+
         elif event_type == "message_edit":
             text = event["object"]["text"]
             peer_id = event["object"]["peer_id"]
             user_id = event["object"]["from_id"]
 
+            if "reply_message" in event["object"]:
+                reply_message = {
+                    "text": event["object"]["reply_message"]["text"],
+                    "peer_id": event["object"]["reply_message"]["peer_id"],
+                    "user_id": event["object"]["reply_message"]["from_id"]
+                }
+
         elif event_type in ("wall_reply_new", "wall_reply_edit"):
             text = event["object"]["text"]
             owner_id = event["object"]["owner_id"]
@@ -43,5 +61,6 @@ def get_event_params(event: dict, event_type: str) -> dict:
         "user_id": user_id,
         "peer_id": peer_id,
         "post_id": post_id,
-        "owner_id": owner_id
+        "owner_id": owner_id,
+        "reply_message": reply_message
     }
