@@ -1,10 +1,13 @@
 from typing import Any
 import aiohttp
 
+from .core import VERSION
+
 
 class Dispatcher:
     def __init__(self, event: dict, token: str, text: str = None, user_id: int = None, peer_id: int = None,
-                 post_id: int = None, owner_id: int = None, chain_data: Any = None):
+                 post_id: int = None, owner_id: int = None, reply_text: str = None, reply_user_id: int = None,
+                 reply_peer_id: int = None, chain_data: Any = None):
         self.token = token
         self.user_id = user_id
         self.peer_id = peer_id
@@ -12,6 +15,9 @@ class Dispatcher:
         self.owner_id = owner_id
         self.event = event
         self.text = text
+        self.reply_text = reply_text
+        self.reply_user_id = reply_user_id
+        self.reply_peer_id = reply_peer_id
         self.chain_data = chain_data
 
     async def answer(self, text: str, attachment: str = None, keyboard: str = None) -> None:
@@ -20,7 +26,7 @@ class Dispatcher:
             params += f"&attachment={attachment}"
         if keyboard is not None:
             params += f"keyboard={keyboard}"
-        params += f"&access_token={self.token}&v=5.126"
+        params += f"&access_token={self.token}&v={VERSION}"
 
         async with aiohttp.ClientSession() as session:
             await session.post("https://api.vk.com/method/messages.send", params=params)
@@ -31,7 +37,7 @@ class Dispatcher:
             params += f"&attachment={attachment}"
         if keyboard is not None:
             params += f"&keyboard={keyboard}"
-        params += f"&access_token={self.token}&v=5.126"
+        params += f"&access_token={self.token}&v={VERSION}"
 
         async with aiohttp.ClientSession() as session:
             await session.post("https://api.vk.com/method/messages.send", params=params)
@@ -40,19 +46,19 @@ class Dispatcher:
         params = f"owner_id={self.owner_id}&post_id={self.post_id}&message={text}"
         if attachment is not None:
             params += f"&attachment={attachment}"
-        params += f"&access_token={self.token}&v=5.126"
+        params += f"&access_token={self.token}&v={VERSION}"
 
         async with aiohttp.ClientSession() as session:
             await session.post("https://api.vk.com/method/wall.createComment", params=params)
 
     async def mark_as_read(self) -> None:
-        params = f"peer_id={self.peer_id}&access_token={self.token}&v=5.126"
+        params = f"peer_id={self.peer_id}&access_token={self.token}&v={VERSION}"
 
         async with aiohttp.ClientSession() as session:
             await session.post("https://api.vk.com/method/messages.markAsRead", params=params)
 
     async def set_typing_status(self, typing_status: str = "typing") -> None:
-        params = f"peer_id={self.peer_id}&type={typing_status}&access_token={self.token}&v=5.126"
+        params = f"peer_id={self.peer_id}&type={typing_status}&access_token={self.token}&v={VERSION}"
 
         async with aiohttp.ClientSession() as session:
             await session.post("https://api.vk.com/method/messages.setActivity", params=params)
@@ -64,6 +70,9 @@ def get_dispatcher_by_event(token: str, event: dict, event_params: dict, chain_d
     peer_id = event_params["peer_id"]
     post_id = event_params["post_id"]
     owner_id = event_params["owner_id"]
+    reply_message = event_params["reply_message"]
 
     return Dispatcher(event=event, token=token, text=text, user_id=user_id, peer_id=peer_id,
-                      post_id=post_id, owner_id=owner_id, chain_data=chain_data)
+                      post_id=post_id, owner_id=owner_id, reply_text=reply_message.get("text"),
+                      reply_peer_id=reply_message.get("peer_id"), reply_user_id=reply_message.get("user_id"),
+                      chain_data=chain_data)
