@@ -39,8 +39,8 @@ class Handler:
 
 class CustomHandler(Handler):
     def __call__(self, func):
-        async def wrapper(token: str, event: dict, event_type: str):
-            await func(get_dispatcher_by_event(token, event, event_type))
+        async def wrapper(token: str, event: dict, event_params: dict, chain_data: Any):
+            await func(get_dispatcher_by_event(token, event, event_params, chain_data))
 
         handler = CustomHandler(self.condition, self.is_lower, wrapper)
         handler.event_type = self.event_type
@@ -59,7 +59,7 @@ class WallReplyNewHandler(Handler):
     event_type = "wall_reply_new"
 
 
-class WallReplyEditHandler(WallReplyNewHandler):
+class WallReplyEditHandler(Handler):
     event_type = "wall_reply_edit"
 
 
@@ -71,7 +71,7 @@ class BoardPostNewHandler(Handler):
     event_type = "board_post_new"
 
 
-class BoardPostEditHandler(BoardPostNewHandler):
+class BoardPostEditHandler(Handler):
     event_type = "board_post_edit"
 
 
